@@ -1,5 +1,6 @@
 package Catalyst::Action::REST;
-$Catalyst::Action::REST::VERSION = '1.17';
+$Catalyst::Action::REST::VERSION = '1.18';
+use utf8;
 use Moose;
 use namespace::autoclean;
 
@@ -17,6 +18,8 @@ sub BUILDARGS {
     return $class->SUPER::BUILDARGS($config, @_);
 }
 
+=encoding utf-8
+
 =head1 NAME
 
 Catalyst::Action::REST - Automated REST Method Dispatching
@@ -251,9 +254,11 @@ Colin Newell <colin@opusvl.com>
 
 Wallace Reis E<lt>wreis@cpan.orgE<gt>
 
+André Walker (andrewalker) <andre@cpan.org>
+
 =head1 COPYRIGHT
 
-Copyright (c) 2006-2012 the above named AUTHOR and CONTRIBUTORS
+Copyright (c) 2006-2015 the above named AUTHOR and CONTRIBUTORS
 
 =head1 LICENSE
 
